Terms
=====

A package of the forcefield terms used in `CGExplore`.

.. toctree::
  :maxdepth: 1

  Terms module <_autosummary/cgexplore.terms>

As with the discussion of the :class:`cgexplore.forcefields.ForceFieldLibrary`,
all terms have the actual term (e.g., :class:`cgexplore.terms.Bond`) and a
`Target` and `TargerRange` class, which assist the user in defining variable
forcefields for a single term.



Bonds
-----

.. toctree::
  :maxdepth: 1

  Bond <_autosummary/cgexplore.terms.Bond>
  TargetBond <_autosummary/cgexplore.terms.TargetBond>
  TargetBondRange <_autosummary/cgexplore.terms.TargetBondRange>
  TargetPairedBondRange <_autosummary/cgexplore.terms.TargetPairedBondRange>
  TargetMartiniBond <_autosummary/cgexplore.terms.TargetMartiniBond>
  MartiniBondRange <_autosummary/cgexplore.terms.MartiniBondRange>

Angles
------

.. toctree::
  :maxdepth: 1

  Angle <_autosummary/cgexplore.terms.Angle>
  TargetAngle <_autosummary/cgexplore.terms.TargetAngle>
  TargetAngleRange <_autosummary/cgexplore.terms.TargetAngleRange>
  TargetPyramidAngle <_autosummary/cgexplore.terms.TargetPyramidAngle>
  PyramidAngleRange <_autosummary/cgexplore.terms.PyramidAngleRange>
  CosineAngle <_autosummary/cgexplore.terms.CosineAngle>
  TargetCosineAngle <_autosummary/cgexplore.terms.TargetCosineAngle>
  TargetCosineAngleRange <_autosummary/cgexplore.terms.TargetCosineAngleRange>
  TargetMartiniAngle <_autosummary/cgexplore.terms.TargetMartiniAngle>
  MartiniAngleRange <_autosummary/cgexplore.terms.MartiniAngleRange>
  FoundAngle <_autosummary/cgexplore.terms.FoundAngle>



Torsions
--------

.. toctree::
  :maxdepth: 1

  Torsion <_autosummary/cgexplore.terms.Torsion>
  TargetTorsion <_autosummary/cgexplore.terms.TargetTorsion>
  TargetTorsionRange <_autosummary/cgexplore.terms.TargetTorsionRange>
  TargetMartiniTorsion <_autosummary/cgexplore.terms.TargetMartiniTorsion>
  FoundTorsion <_autosummary/cgexplore.terms.FoundTorsion>

Nonbonded
---------

.. toctree::
  :maxdepth: 1

  Nonbonded <_autosummary/cgexplore.terms.Nonbonded>
  TargetNonbonded <_autosummary/cgexplore.terms.TargetNonbonded>
  TargetNonbondedRange <_autosummary/cgexplore.terms.TargetNonbondedRange>



Utilities
---------

.. toctree::
  :maxdepth: 1

  find_angles <_autosummary/cgexplore.terms.find_angles>
  find_torsions <_autosummary/cgexplore.terms.find_torsions>

